@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/fs/dc/dc-fs.cpp $
- * $Id: dc-fs.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/fs/dc/dc-fs.cpp $
+ * $Id: dc-fs.cpp 30944 2008-02-23 22:50:18Z sev $
  */
 
 #if defined(__DC__)
@@ -56,13 +56,13 @@ public:
 	 */
 	RoninCDFilesystemNode(const String &path, bool verify);
 
-	virtual bool exists() const { return true; }		//FIXME: this is just a stub
+	virtual bool exists() const { return _isValid; }
 	virtual String getDisplayName() const { return _displayName; }
 	virtual String getName() const { return _displayName; }
 	virtual String getPath() const { return _path; }
 	virtual bool isDirectory() const { return _isDirectory; }
-	virtual bool isReadable() const { return true; }	//FIXME: this is just a stub
-	virtual bool isWritable() const { return true; }	//FIXME: this is just a stub
+	virtual bool isReadable() const { return true; }
+	virtual bool isWritable() const { return false; }
 
 	virtual AbstractFilesystemNode *getChild(const String &n) const;
 	virtual bool getChildren(AbstractFSList &list, ListMode mode, bool hidden) const;
