@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/fs/symbian/symbian-fs.cpp $
- * $Id: symbian-fs.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/fs/symbian/symbian-fs.cpp $
+ * $Id: symbian-fs.cpp 30944 2008-02-23 22:50:18Z sev $
  */
 
 #if defined (__SYMBIAN32__) 
@@ -58,13 +58,19 @@ public:
 	 */
 	SymbianFilesystemNode(const String &path);
 	
-	virtual bool exists() const { return true; }		//FIXME: this is just a stub
+	virtual bool exists() const {
+		TFileName fname;
+		TPtrC8 ptr((const unsigned char*)_path.c_str(),_path.size());
+		fname.Copy(ptr);
+		TBool fileExists = BaflUtils::FileExists(CEikonEnv::Static()->FsSession(), fname);
+		return fileExists;
+	}
 	virtual String getDisplayName() const { return _displayName; }
 	virtual String getName() const { return _displayName; }
 	virtual String getPath() const { return _path; }
 	virtual bool isDirectory() const { return _isDirectory; }
-	virtual bool isReadable() const { return true; }	//FIXME: this is just a stub
-	virtual bool isWritable() const { return true; }	//FIXME: this is just a stub
+	virtual bool isReadable() const { return access(_path.c_str(), R_OK) == 0; }	//FIXME: this is just a stub
+	virtual bool isWritable() const { return access(_path.c_str(), W_OK) == 0; }	//FIXME: this is just a stub
 
 	virtual AbstractFilesystemNode *getChild(const String &n) const;
 	virtual bool getChildren(AbstractFSList &list, ListMode mode, bool hidden) const;
