@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/platform/dc/vmsave.cpp $
- * $Id: vmsave.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/platform/dc/vmsave.cpp $
+ * $Id: vmsave.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -164,13 +164,8 @@ static bool tryDelete(const char *filename, int vm)
   if (!vmsfs_get_superblock(&info, &super))
     return false;
 
-#if 0
-  // FIXME: implement this function in vmsfs...
   if (!vmsfs_delete_file(&super, filename))
     return false;
-#else
-  return false;
-#endif
 
   return true;
 }
