@@ -36,7 +36,7 @@
 #include <arm7/clock.h>
 #include <stdlib.h>
 #include <string.h>
-#include <registers_alt.h>
+//#include <registers_alt.h>	// not needed in current libnds
 #include <NDS/scummvm_ipc.h>
 //////////////////////////////////////////////////////////////////////
 #ifdef USE_DEBUGGER
@@ -261,6 +261,9 @@ uint16 powerManagerWrite(uint32 command, u32 data, bool enable) {
   REG_SPICNT = SPI_ENABLE | SPI_BAUD_1MHz;
   REG_SPIDATA = enable? (result | data): (result & ~data);
   SerialWaitBusy();
+  
+  // FIXME: This function should either return something, or have a comment
+  // explaining why it is valid for it to not return something. :-)
 }
 
 /*
