@@ -24,13 +24,28 @@
 #define _DSMAIN_H
 
 #include <nds.h>
-#include "stdafx.h"
 #include "osystem_ds.h"
 #include "scummconsole.h"
 #include "NDS/scummvm_ipc.h"
 
 namespace DS {
 
+
+enum controlType {
+	CONT_SCUMM_ORIGINAL,
+	CONT_SCUMM_SAMNMAX,
+	CONT_SKY,
+	CONT_SIMON,
+	CONT_FUTURE_WARS,
+	CONT_AGI,
+	CONT_GOBLINS
+};
+
+struct gameListType {
+	char 			gameId[16];
+	controlType 	control;
+};
+
 // Pen reading functions
 void 	penInit();
 void 	penUpdate();
@@ -60,6 +75,8 @@ void 	displayMode16BitFlipBuffer();
 // Get address of current back buffer
 u16* 	get16BitBackBuffer();
 u16* 	get8BitBackBuffer();
+s32 	get8BitBackBufferStride();
+u16*	getScalerBuffer();
 
 void 	setTalkPos(int x, int y);
 void 	setTopScreenTarget(int x, int y);
@@ -83,7 +100,9 @@ void 	VBlankHandler();
 
 // Sam and Max Stuff
 void 	setGameID(int id);
-void 	setCursorIcon(const u8* icon, uint w, uint h, byte keycolor);
+void 	setCursorIcon(const u8* icon, uint w, uint h, byte keycolor, int hotspotX, int hotspotY);
+void	setShowCursor(bool enable);
+void	setMouseCursorVisible(bool visible);
 
 // Shake
 void 	setShakePos(int shakePos);
@@ -108,9 +127,11 @@ void 	setLeftHanded(bool enable);
 void 	setTouchXOffset(int x);
 void 	setTouchYOffset(int y);
 void 	setUnscaledMode(bool enable);
+void	setSnapToBorder(bool enable);
 void 	setIndyFightState(bool st);
 bool 	getIndyFightState();
 bool    isCpuScalerEnabled();
+void	setCpuScalerEnable(bool enable);
 
 // Display
 bool 	getIsDisplayMode8Bit();
@@ -123,7 +144,12 @@ void	fastRamReset();
 void*	fastRamAlloc(int size);
 
 
+gameListType* getCurrentGame();
+
+
 }
 
 
+int cygprofile_getHBlanks();
+
 #endif
