@@ -23,7 +23,6 @@
 #ifndef _DSOPTIONS_H_
 #define _DSOPTIONS_H_
 
-#include "stdafx.h"
 
 #include "common/scummsys.h"
 #include "common/str.h"
@@ -43,7 +42,8 @@ public:
 	
 protected:
 	virtual void handleCommand(GUI::CommandSender *sender, uint32 cmd, uint32 data);
-
+	void togglePause();
+	void updateConfigManager();
 
 	GUI::SliderWidget* _touchX;
 	GUI::SliderWidget* _touchY;
@@ -53,12 +53,18 @@ protected:
 	GUI::CheckboxWidget* _indyFightCheckbox;
 	GUI::CheckboxWidget* _highQualityAudioCheckbox;
 	GUI::CheckboxWidget* _disablePowerOff;
+	GUI::CheckboxWidget* _showCursorCheckbox;
+	GUI::CheckboxWidget* _snapToBorderCheckbox;
+
+	GUI::CheckboxWidget* _hardScaler;
 	GUI::CheckboxWidget* _cpuScaler;
 	
 #ifdef DS_SCUMM_BUILD
 	Scumm::SaveLoadChooser* _delDialog;
 #endif
 
+	bool	_radioButtonMode;
+
 };
 
 extern void showOptionsDialog();
