@@ -30,7 +30,7 @@ extern u8 _dldi_driver_name;
 static inline LPIO_INTERFACE DLDI_GetInterface(void) {
 #ifdef NDS
 	// NDM: I'm really not sure about this change ARM9 - ARM7
-	REG_EXMEMCNT &= ~(ARM7_OWNS_ROM | ARM7_OWNS_CARD);
+	REG_EXEMEMCNT &= ~(ARM7_OWNS_ROM | ARM7_OWNS_CARD);
 #endif // defined NDS
 	return &_io_dldi;
 }
