@@ -20,11 +20,22 @@
  *
  */
 
-#include "stdafx.h"
 #include <string.h>
 #include "nds/dma.h"
 #include "osystem_ds.h"
 
+/*
+extern "C" time_t __wrap_time(time_t* t) {
+	if (t) {
+		*t = OSystem_DS::instance()->getMillis() / 1000;
+	}
+
+	return OSystem_DS::instance()->getMillis() / 1000;
+}
+*/
+
+
+
 time_t DS_time(time_t) {
 	if (OSystem_DS::instance()) {
 		return 0xABCD1234 + (OSystem_DS::instance()->getMillis() / 1000);
