@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/platform/iphone/osys_iphone.cpp $
- * $Id: osys_iphone.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/platform/iphone/osys_iphone.cpp $
+ * $Id: osys_iphone.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -27,15 +27,14 @@
 
 #include <CoreGraphics/CGDirectDisplay.h>
 #include <CoreSurface/CoreSurface.h>
-#include <AudioToolbox/AudioQueue.h>
 #include <unistd.h>
 #include <pthread.h>
 
-#include "common/system.h"
 #include "common/scummsys.h"
 #include "common/util.h"
 #include "common/rect.h"
-#include "common/events.h"
+#include "common/file.h"
+#include "common/fs.h"
 
 #include "base/main.h"
 
@@ -55,6 +54,7 @@ const OSystem::GraphicsMode OSystem_IPHONE::s_supportedGraphicsModes[] = {
 AQCallbackStruct OSystem_IPHONE::s_AudioQueue;
 SoundProc OSystem_IPHONE::s_soundCallback = NULL;
 void *OSystem_IPHONE::s_soundParam = NULL;
+bool OSystem_IPHONE::s_is113OrHigher = false;
 
 OSystem_IPHONE::OSystem_IPHONE() :
 	_savefile(NULL), _mixer(NULL), _timer(NULL), _offscreen(NULL),
@@ -1173,8 +1173,47 @@ OSystem *OSystem_IPHONE_create() {
 	return new OSystem_IPHONE();
 }
 
+const char* OSystem_IPHONE::getConfigPath() {
+	if (s_is113OrHigher)
+		return SCUMMVM_PREFS_PATH;
+	else
+		return SCUMMVM_OLD_PREFS_PATH;
+}
+
+const char* OSystem_IPHONE::getSavePath() {
+	if (s_is113OrHigher)
+		return SCUMMVM_SAVE_PATH;
+	else
+		return SCUMMVM_OLD_SAVE_PATH;
+}
+
+void OSystem_IPHONE::migrateApp() {
+	// Migrate to the new 1.1.3 directory structure, if needed.
+	
+	FilesystemNode file("/var/mobile");
+	if (file.exists() && file.isDirectory()) {
+		// We have 1.1.3 or above.
+		s_is113OrHigher = true;
+		file = FilesystemNode(SCUMMVM_ROOT_PATH);
+		if (!file.exists()) {
+			system("mkdir " SCUMMVM_ROOT_PATH);
+			system("mkdir " SCUMMVM_SAVE_PATH);
+
+			// Copy over the prefs file
+			system("cp " SCUMMVM_OLD_PREFS_PATH " " SCUMMVM_PREFS_PATH);
+
+			file = FilesystemNode(SCUMMVM_OLD_SAVE_PATH);
+			// Copy over old savegames to the new directory.
+			if (file.exists() && file.isDirectory())			
+				system("cp " SCUMMVM_OLD_SAVE_PATH "/* " SCUMMVM_SAVE_PATH "/");
+		}
+	}
+}
+
 void iphone_main(int argc, char *argv[]) {
 	
+	OSystem_IPHONE::migrateApp();
+
 	// Redirect stdout and stderr if we're launching from the Springboard.
 	if (argc == 2 && strcmp(argv[1], "--launchedFromSB") == 0) {
 		FILE *newfp = fopen("/tmp/scummvm.log", "a");
