@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/platform/ps2/Gs2dScreen.h $
- * $Id: Gs2dScreen.h 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/platform/ps2/Gs2dScreen.h $
+ * $Id: Gs2dScreen.h 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -28,6 +28,7 @@
 
 #include "sysdefs.h"
 #include "backends/platform/ps2/DmaPipe.h"
+#include "graphics/surface.h"
 
 enum TVMode {
 	TV_DONT_CARE = 0,
@@ -56,13 +57,16 @@ public:
 
 	void copyPrintfOverlay(const uint8* buf);
 	void clearPrintfOverlay(void);
+	void clearScreen(void);
+
+	Graphics::Surface *lockScreen();
+	void unlockScreen();
 
 	void copyScreenRect(const uint8 *buf, int pitch, int x, int y, int w, int h);
 	void setPalette(const uint32 *pal, uint8 start, uint16 num);
 	void updateScreen(void);
 	void grabPalette(uint32 *pal, uint8 start, uint16 num);
-	Graphics::Surface *lockScreen();
-	void unlockScreen();
+	void grabScreen(Graphics::Surface *surf);
 	//- overlay routines
 	void copyOverlayRect(const uint16 *buf, uint16 pitch, uint16 x, uint16 y, uint16 w, uint16 h);
 	void grabOverlay(uint16 *buf, uint16 pitch);
@@ -94,13 +98,12 @@ private:
 	uint32 _clutPtrs[3];    //   vram pointers
 	uint32 _texPtrs[4];     //
 
+	Graphics::Surface _framebuffer;
 	uint16 _width, _height, _pitch;
 	int16  _mouseX, _mouseY, _hotSpotX, _hotSpotY;
 	uint32 _mouseScaleX, _mouseScaleY;
 	uint8  _mTraCol;
 
-	Graphics::Surface _framebuffer;
-
 	int _shakePos;
 
 	bool _showMouse, _showOverlay, _screenChanged, _overlayChanged, _clutChanged;
