@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/platform/ps2/irxboot.cpp $
- * $Id: irxboot.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/platform/ps2/irxboot.cpp $
+ * $Id: irxboot.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -34,8 +34,8 @@
 
 extern void sioprintf(const char *zFormat, ...);
 
-static const char hddArg[] = "-o" "\0" "4" "\0" "-n" "\0" "20";
-static const char pfsArg[] = "-m" "\0" "2" "\0" "-o" "\0" "16" "\0" "-n" "\0" "40" /*"\0" "-debug"*/;
+static const char hddArg[] = "-o" "\0" "8" "\0" "-n" "\0" "20";
+static const char pfsArg[] = "-m" "\0" "2" "\0" "-o" "\0" "32" "\0" "-n" "\0" "72"; // "\0" "-debug";
 
 IrxFile irxFiles[] = {
 	{ "SIO2MAN", BIOS, NOTHING, NULL, 0 },
@@ -209,6 +209,7 @@ int loadIrxModules(int device, const char *irxPath, IrxReference **modules) {
 		}
 		curModule++;
 	}
+
 	*modules = resModules;
 	sioprintf("List of %d modules:", curModule - resModules);
 	for (int i = 0; i < curModule - resModules; i++)
