@@ -18,14 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/platform/ps2/ps2time.cpp $
- * $Id: ps2time.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/platform/ps2/ps2time.cpp $
+ * $Id: ps2time.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
 #include "backends/platform/ps2/systemps2.h"
 #include "eecodyvdfs.h"
 #include <osd_config.h>
+#include <time.h>
+
 #define FROM_BCD(a) ((a >> 4) * 10 + (a & 0xF))
 
 static int	  g_timeSecs;
@@ -104,15 +106,10 @@ void OSystem_PS2::readRtcTime(void) {
 }
 
 extern "C" time_t time(time_t *p) {
-	if (p) *p = (time_t)g_timeSecs;
 	return (time_t)g_timeSecs;
 }
 
 extern "C" struct tm *localtime(const time_t *p) {
-	// FIXME: This function should actually use the value in *p!
-	// But the work needed for that is not necessary -- just implement
-	// OSystem::getTimeAndDate using the code provided here, and
-	// ditch the custom time & localtime methods.
 	uint32 currentSecs = g_timeSecs + (msecCount - g_lastTimeCheck) / 1000;
 	if (currentSecs >= SECONDS_PER_DAY) {
 		buildNewDate(+1);
