@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/platform/ps2/savefile.h $
- * $Id: savefile.h 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/platform/ps2/savefile.h $
+ * $Id: savefile.h 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -42,10 +42,15 @@ public:
 	virtual Common::OutSaveFile *openForSaving(const char *filename);
 	virtual void listSavefiles(const char *prefix, bool *marks, int num);
 
+	virtual Common::StringList listSavefiles(const char *regex);
+	virtual bool removeSavefile(const char *filename);
+
+	/** Get the path to the save game directory. */
+	virtual const char *getSavePath() const;
+
 	void writeSaveNonblocking(char *name, void *buf, uint32 size);
 	void saveThread(void);
 	void quit(void);
-	
 private:
 	bool setupIcon(const char *dest, const char *ico, const char *descr1, const char *descr2);
 
