@@ -14,7 +14,7 @@
 		MACRO			DISABLE_PARALLACTION	// LIB:scummvm_parallaction.lib		
 		MACRO			DISABLE_TOUCHE		// LIB:scummvm_touche.lib
 		MACRO			DISABLE_DRASCULA	// LIB:scummvm_drascula.lib
-		MACRO			DISABLE_IGOR	// LIB:scummvm_igor.lib
+		MACRO			DISABLE_IGOR		// LIB:scummvm_igor.lib
 	";
 
 	##
@@ -364,7 +364,7 @@ if (1) # all regular combo's
 #		//MACRO			DISABLE_KYRA		// LIB:scummvm_kyra.lib
 #	$DefaultBottomMacros";
 
-	$SDK_Variations{'ALL'}{'test_lure'} = "$DefaultTopMacros
+	$SDK_Variations{'ALL'}{'lure'} = "$DefaultTopMacros
 		MACRO			DISABLE_SCUMM		// LIB:scummvm_scumm.lib
 		MACRO			DISABLE_AGOS		// LIB:scummvm_agos.lib
 		MACRO			DISABLE_SKY			// LIB:scummvm_sky.lib
@@ -395,7 +395,7 @@ if (1) # all regular combo's
 		MACRO			DISABLE_IGOR		// LIB:scummvm_igor.lib
 	$DefaultBottomMacros";
 
-	$SDK_Variations{'ALL'}{'test_agi'} = "$DefaultTopMacros
+	$SDK_Variations{'ALL'}{'agi'} = "$DefaultTopMacros
 		MACRO			DISABLE_SCUMM		// LIB:scummvm_scumm.lib
 		MACRO			DISABLE_AGOS		// LIB:scummvm_agos.lib
 		MACRO			DISABLE_SKY		// LIB:scummvm_sky.lib
