@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/platform/symbian/src/SymbianOS.cpp $
- * $Id: SymbianOS.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/platform/symbian/src/SymbianOS.cpp $
+ * $Id: SymbianOS.cpp 30944 2008-02-23 22:50:18Z sev $
  */
 
 #include <eikenv.h> // for CEikonEnv::Static() @ Symbian::FatalError()
@@ -35,6 +35,13 @@
 
 #include "..\..\sdl\main.cpp"
 
+#ifdef SAMPLES_PER_SEC_8000 // the GreanSymbianMMP format cannot handle values for defines :(
+  #define SAMPLES_PER_SEC 8000
+#else
+  #define SAMPLES_PER_SEC 16000
+#endif
+
+
 ////////// extern "C" ///////////////////////////////////////////////////
 namespace Symbian {
 
@@ -52,9 +59,8 @@ void FatalError(const char *msg) {
 }
 
 // make this easily available everywhere
-char* GetExecutablePath()
-{
-	return CSDLApp::GetExecutablePathCStr();	
+char* GetExecutablePath() {
+	return CSDLApp::GetExecutablePathCStr();
 }
 
 } // namespace Symbian {
@@ -93,7 +99,7 @@ void OSystem_SDL_Symbian::setFeatureState(Feature f, bool enable) {
 			break;
 		case kFeatureDisableKeyFiltering:
 			GUI::Actions::Instance()->beginMapping(enable);
-			break;;
+			break;
 		default:
 			OSystem_SDL::setFeatureState(f, enable);
 	}
