@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/platform/wince/CEActionsSmartphone.cpp $
- * $Id: CEActionsSmartphone.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/platform/wince/CEActionsSmartphone.cpp $
+ * $Id: CEActionsSmartphone.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -118,6 +118,7 @@ void CEActionsSmartphone::initInstanceGame() {
 	bool is_agi = (gameid == "agi");
 	bool is_parallaction = (gameid == "parallaction");
 	bool is_lure = (gameid == "lure");
+	bool is_feeble = (gameid == "feeble");
 
 	GUI_Actions::initInstanceGame();
 
@@ -127,7 +128,7 @@ void CEActionsSmartphone::initInstanceGame() {
 
 	// Initialize keys for different actions
 	// Save
-	if (is_simon || is_sword2 || is_gob || is_kyra || is_touche)
+	if (is_simon || is_sword2 || is_gob || is_kyra || is_touche || is_feeble)
 		_action_enabled[SMARTPHONE_ACTION_SAVE] = false;
 	else if (is_queen) {
 		_action_enabled[SMARTPHONE_ACTION_SAVE] = true;
@@ -150,7 +151,7 @@ void CEActionsSmartphone::initInstanceGame() {
 	}
 	// Skip
 	_action_enabled[SMARTPHONE_ACTION_SKIP] = true;
-	if (is_simon || is_sky || is_sword2 || is_queen || is_sword1 || is_gob || is_saga || is_kyra || is_touche || is_lure)
+	if (is_simon || is_sky || is_sword2 || is_queen || is_sword1 || is_gob || is_saga || is_kyra || is_touche || is_lure || is_feeble)
 		_key_action[SMARTPHONE_ACTION_SKIP].setKey(VK_ESCAPE);
 	else
 		_key_action[SMARTPHONE_ACTION_SKIP].setKey(KEY_ALL_SKIP);
