@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/backends/platform/wince/wince-sdl.cpp $
- * $Id: wince-sdl.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/backends/platform/wince/wince-sdl.cpp $
+ * $Id: wince-sdl.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -786,7 +786,7 @@ bool OSystem_WINCE3::setSoundCallback(SoundProc proc, void *param) {
 
 	// Add sound thread priority
 	if (!ConfMan.hasKey("sound_thread_priority")) {
-		thread_priority = THREAD_PRIORITY_NORMAL;
+		thread_priority = THREAD_PRIORITY_ABOVE_NORMAL;
 	}
 	else
 		thread_priority = ConfMan.getInt("sound_thread_priority");
