@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/common/hashmap.h $
- * $Id: hashmap.h 30493 2008-01-15 12:28:56Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/common/hashmap.h $
+ * $Id: hashmap.h 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -116,6 +116,11 @@ public:
 	int lookupAndCreateIfMissing(const Key &key);
 	void expand_array(uint newsize);
 
+	class Iterator;
+	class ConstIterator;
+	friend class Iterator;
+	friend class ConstIterator;
+
 	/**
 	 * Simple HashMap iterator implementation.
 	 */
