@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/agi/detection.cpp $
- * $Id: detection.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/agi/detection.cpp $
+ * $Id: detection.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -1929,8 +1929,8 @@ static const AGIGameDescription gameDescriptions[] = {
 	FANMADE("Jiggy Jiggy Uh! Uh!", "bc331588a71e7a1c8840f6cc9b9487e4"),
 	FANMADE("Jimmy In: The Alien Attack (v0.1)", "a4e9db0564a494728de7873684a4307c"),
 	FANMADE("Joe McMuffin In \"What's Cooking, Doc\" (v1.0)", "8a3de7e61a99cb605fa6d233dd91c8e1"),
-	FANMADE_LVF("Jolimie, le Village Maudit (v0.5)", "21818501636b3cb8ad5de5c1a66de5c2", Common::FR_FRA, GF_AGIMOUSE|GF_AGIPAL, 0x2936),
-	FANMADE_LVF("Jolimie, le Village Maudit (v1.1)", "68d7aef1161bb5972fe03efdf29ccb7f", Common::FR_FRA, GF_AGIMOUSE|GF_AGIPAL, 0x2936),
+	FANMADE_LVF("Jolimie, le Village Maudit (v0.5)", "21818501636b3cb8ad5de5c1a66de5c2", Common::FR_FRA, 0x2936, GF_AGIMOUSE|GF_AGIPAL),
+	FANMADE_LVF("Jolimie, le Village Maudit (v1.1)", "68d7aef1161bb5972fe03efdf29ccb7f", Common::FR_FRA, 0x2936, GF_AGIMOUSE|GF_AGIPAL),
 	FANMADE("Journey Of Chef", "aa0a0b5a6364801ae65fdb96d6741df5"),
 	FANMADE("Jukebox (v1.0)", "c4b9c5528cc67f6ba777033830de7751"),
 	FANMADE("Justin Quest (v1.0 in development)", "103050989da7e0ffdc1c5e1793a4e1ec"),
@@ -2125,7 +2125,18 @@ Common::EncapsulatedADGameDesc fallbackDetector(const FSList *fslist) {
 		// so we don't have to change it here.
 		matchedUsingFilenames = true;
 
-		if (allFiles.contains("pal.101")) { // Check if it is AGIPAL
+		// Check for AGIPAL by checking for existence of any of the files "pal.100" - "pal.109"
+		bool agipal = false;
+		char agipalFile[] = "pal.xxx";
+		for (uint i = 100; i <= 109; i++) {
+			sprintf(agipalFile, "pal.%d", i);
+			if (allFiles.contains(agipalFile)) {
+				agipal = true; // We found a file "pal.x" where 100 <= x <= 109 so it's AGIPAL
+				break;
+			}
+		}
+
+		if (agipal) { // Check if it is AGIPAL
 			description = "Unknown v2 AGIPAL Game";
 			g_fallbackDesc.features |= GF_AGIPAL; // Add AGIPAL feature flag
 		} else { // Not AGIPAL so just plain v2
@@ -2213,7 +2224,7 @@ Common::EncapsulatedADGameDesc fallbackDetector(const FSList *fslist) {
 	// Check if we found a match with any of the fallback methods
 	Common::EncapsulatedADGameDesc result;
 	if (matchedUsingWag || matchedUsingFilenames) {
-		extra = description + " " + extra; // Let's combine the description and extra
+		extra = description + (!extra.empty() ? " " : "") + extra; // Let's combine the description and extra
 		result = Common::EncapsulatedADGameDesc((const Common::ADGameDescription *)&g_fallbackDesc, gameid, extra);
 
 		printf("Your game version has been detected using fallback matching as a\n");
