@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/gob/detection.cpp $
- * $Id: detection.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/gob/detection.cpp $
+ * $Id: detection.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -109,6 +109,19 @@ static const GOBGameDescription gameDescriptions[] = {
 		kFeaturesNone,
 		"intro"
 	},
+	{ // Supplied by raziel_ in bug report #1891864
+		{
+			"gob1",
+			"VGA",
+			AD_ENTRY1s("intro.stk", "e157cb59c6d330ca70d12ab0ef1dd12b", 288972),
+			EN_GRB,
+			kPlatformPC,
+			Common::ADGF_NO_FLAGS
+		},
+		kGameTypeGob1,
+		kFeaturesAdlib,
+		"intro"
+	},
 	{ // CD 1.000 version.
 		{
 			"gob1cd",
@@ -399,6 +412,19 @@ static const GOBGameDescription gameDescriptions[] = {
 		kFeaturesAdlib,
 		"intro"
 	},
+	{ // Supplied by raziel_ in bug report #1891867
+		{
+			"gob2",
+			"",
+			AD_ENTRY1s("intro.stk", "25a99827cd59751a80bed9620fb677a0", 893302),
+			EN_USA,
+			kPlatformPC,
+			Common::ADGF_NO_FLAGS
+		},
+		kGameTypeGob2,
+		kFeaturesAdlib,
+		"intro"
+	},
 	{
 		{
 			"gob2",
@@ -425,6 +451,19 @@ static const GOBGameDescription gameDescriptions[] = {
 		kFeaturesAdlib,
 		"intro"
 	},
+	{ // Supplied by fac76 in bug report #1883808
+		{
+			"gob2",
+			"",
+			AD_ENTRY1s("intro.stk", "eebf2810122cfd17399260cd1468e994", 554014),
+			EN_ANY,
+			kPlatformAmiga,
+			Common::ADGF_NO_FLAGS
+		},
+		kGameTypeGob2,
+		kFeaturesNone,
+		"intro"
+	},
 	{
 		{
 			"gob2",
@@ -574,11 +613,24 @@ static const GOBGameDescription gameDescriptions[] = {
 			"Interactive Demo",
 			AD_ENTRY1("intro.stk", "4b278c2678ea01383fd5ca114d947eea"),
 			UNK_LANG,
-			kPlatformPC,
+			kPlatformAmiga,
 			Common::ADGF_DEMO
 		},
 		kGameTypeGob2,
-		kFeaturesAdlib,
+		kFeaturesNone,
+		"intro"
+	},
+	{ // Supplied by polluks in bug report #1895126
+		{
+			"gob2",
+			"Interactive Demo",
+			AD_ENTRY1s("intro.stk", "9fa85aea959fa8c582085855fbd99346", 553063),
+			UNK_LANG,
+			kPlatformAmiga,
+			Common::ADGF_DEMO
+		},
+		kGameTypeGob2,
+		kFeaturesNone,
 		"intro"
 	},
 	{
@@ -994,6 +1046,19 @@ static const GOBGameDescription gameDescriptions[] = {
 		kFeaturesAdlib,
 		"intro"
 	},
+	{ // Supplied by raziel_ in bug report #1891869
+		{
+			"gob3",
+			"",
+			AD_ENTRY1s("intro.stk", "16b014bf32dbd6ab4c5163c44f56fed1", 445104),
+			EN_GRB,
+			kPlatformPC,
+			Common::ADGF_NO_FLAGS
+		},
+		kGameTypeGob3,
+		kFeaturesAdlib,
+		"intro"
+	},
 	{ // Supplied by fac76 in bug report #1742716
 		{
 			"gob3",
