@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/gob/util.cpp $
- * $Id: util.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/gob/util.cpp $
+ * $Id: util.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -324,8 +324,17 @@ void Util::waitEndFrame() {
 
 void Util::setScrollOffset(int16 x, int16 y) {
 	processInput();
-	_vm->_video->_scrollOffsetX = x >= 0 ? x : _vm->_draw->_scrollOffsetX;
-	_vm->_video->_scrollOffsetY = y >= 0 ? y : _vm->_draw->_scrollOffsetY;
+
+	if(x >= 0)
+		_vm->_video->_scrollOffsetX = x; 
+	else
+		_vm->_video->_scrollOffsetX = _vm->_draw->_scrollOffsetX;
+
+	if(y >= 0)
+		_vm->_video->_scrollOffsetY = y; 
+	else
+		_vm->_video->_scrollOffsetY = _vm->_draw->_scrollOffsetY;
+
 	_vm->_video->waitRetrace();
 }
 
