@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/kyra/resource.h $
- * $Id: resource.h 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/kyra/resource.h $
+ * $Id: resource.h 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -38,7 +38,7 @@ namespace Kyra {
 
 class ResourceFile {
 public:
-	ResourceFile() : _open(false), _protected(false), _filename() {}
+	ResourceFile() : _mopen(false), _protected(false), _filename() {}
 	virtual ~ResourceFile() {}
 
 	virtual uint8 *getFile(uint file) const = 0;
@@ -48,13 +48,13 @@ public:
 	uint filename() const { return _filename; }
 
 	virtual bool isValid(void) const { return (_filename != 0); }
-	bool isOpen(void) const { return _open; }
+	bool isOpen(void) const { return _mopen; }
 
-	virtual void close() { if (!_protected) _open = false; }
+	virtual void close() { if (!_protected) _mopen = false; }
 	virtual void protect(const bool prot = true) { _protected = prot; }
-	virtual void open() { _open = true; }
+	virtual void open() { _mopen = true; }
 protected:
-	bool _open;
+	bool _mopen;
 	bool _protected;
 	uint _filename;
 };
