@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/lure/menu.cpp $
- * $Id: menu.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/lure/menu.cpp $
+ * $Id: menu.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -34,7 +34,7 @@
 #include "lure/events.h"
 #include "lure/lure.h"
 
-#if defined(_WIN32_WCE)
+#if defined(_WIN32_WCE) || defined(__SYMBIAN32__)
 #define LURE_CLICKABLE_MENUS
 #endif
 
