@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/lure/res_struct.cpp $
- * $Id: res_struct.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/lure/res_struct.cpp $
+ * $Id: res_struct.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -692,6 +692,34 @@ TalkEntryData *TalkData::getResponse(int index) {
 	return *i;
 }
 
+// The following class acts as a container for all the NPC conversations
+
+void TalkDataList::saveToStream(WriteStream *stream) {
+	TalkDataList::iterator i;
+	for (i = begin(); i != end(); ++i) {
+		TalkData *rec = *i;
+		TalkEntryList::iterator i2;
+		
+		for (i2 = rec->entries.begin(); i2 != rec->entries.end(); ++i2) {
+			TalkEntryData *entry = *i2;
+			stream->writeUint16LE(entry->descId);
+		}
+	}
+}
+
+void TalkDataList::loadFromStream(ReadStream *stream) {
+	TalkDataList::iterator i;
+	for (i = begin(); i != end(); ++i) {
+		TalkData *rec = *i;
+		TalkEntryList::iterator i2;
+		
+		for (i2 = rec->entries.begin(); i2 != rec->entries.end(); ++i2) {
+			TalkEntryData *entry = *i2;
+			entry->descId = stream->readUint16LE();
+		}
+	}
+}
+
 // The following class handles a set of coordinates a character should walk to
 // if they're to exit a room to a designated secondary room
 
@@ -1181,9 +1209,11 @@ void BarmanLists::loadFromStream(Common::ReadStream *stream) {
 	uint8 saveVersion = LureEngine::getReference().saveVersion();
 	int numEntries = (saveVersion >= 30) ? 3 : 2;
 
+	reset();
 	for (int index = 0; index < numEntries; ++index) {
 		int16 value = stream->readUint16LE();
-		_barList[index].currentCustomer = (value == 0) ? NULL : &_barList[index].customers[value - 1];
+		_barList[index].currentCustomer = ((value < 1) || (value > NUM_SERVE_CUSTOMERS)) ? NULL : 
+			&_barList[index].customers[value - 1];
 
 		for (int ctr = 0; ctr < NUM_SERVE_CUSTOMERS; ++ctr) {
 			_barList[index].customers[ctr].hotspotId = stream->readUint16LE();
