@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/lure/res_struct.h $
- * $Id: res_struct.h 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/lure/res_struct.h $
+ * $Id: res_struct.h 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -589,7 +589,11 @@ public:
 	TalkEntryData *getResponse(int index);
 };
 
-typedef ManagedList<TalkData *> TalkDataList;
+class TalkDataList: public ManagedList<TalkData *> {
+public:
+	void saveToStream(WriteStream *stream);
+	void loadFromStream(ReadStream *stream);
+};
 
 struct RoomExitCoordinateData {
 	int16 x;
