@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/lure/scripts.cpp $
- * $Id: scripts.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/lure/scripts.cpp $
+ * $Id: scripts.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -438,14 +438,14 @@ void Script::transformPlayer(uint16 v1, uint16 v2, uint16 v3) {
 	hotspot->startX = player->startX - 14;
 	hotspot->startY = player->startY - 10;
 	
-	Hotspot *activeHotspot = res.addHotspot(TRANSFORM_ID);
+	Hotspot *activeHotspot = res.activateHotspot(TRANSFORM_ID);
 	activeHotspot->setActionCtr(0);
 	activeHotspot->setHotspotScript(0x630);
 }
 
-// Marks the jail door in room 14 for closing
+// Marks the town hall door in room 14 for closing
 
-void Script::jailClose(uint16 v1, uint16 v2, uint16 v3) {
+void Script::townHallClose(uint16 v1, uint16 v2, uint16 v3) {
 	RoomExitJoinData *joinRec = Resources::getReference().getExitJoin(0x2719);
 	joinRec->blocked = 1;
 }
@@ -603,6 +603,10 @@ void Script::makeGoewinWork(uint16 v1, uint16 v2, uint16 v3) {
 	goewin->setHotspotScript(0x616);
 	goewin->setDelayCtr(1500);
 	goewin->setTickProc(GOEWIN_SHOP_TICK_PROC);
+
+	// Set walk to position for Goewin whilst she's working
+	goewin->resource()->walkX = 179;
+	goewin->resource()->walkY = 138;
 }
 
 // Sets a character moving to the player's room (if they're not already there)
@@ -700,6 +704,10 @@ void Script::normalGoewin(uint16 v1, uint16 v2, uint16 v3) {
 	hotspot->setCharacterMode(CHARMODE_NONE);
 	hotspot->setDirection(UP);
 	hotspot->setTickProc(STANDARD_CHARACTER_TICK_PROC);
+
+	// Clear walk to position for Goewin so player must walk up to her when interacting
+	hotspot->resource()->walkX = 0;
+	hotspot->resource()->walkY = 0;
 }
 
 // Flags the player as dead
@@ -798,7 +806,7 @@ static const SequenceMethodRecord scriptMethods[] = {
 	{36, Script::displayMessage2},
 	{37, Script::startOilBurner},
 	{38, Script::transformPlayer},
-	{39, Script::jailClose},
+	{39, Script::townHallClose},
 	{40, Script::checkRoomNumber},
 	{41, Script::makeGoewinFollow},
 	{42, Script::doorClose},
