@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/lure/scripts.h $
- * $Id: scripts.h 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/lure/scripts.h $
+ * $Id: scripts.h 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -115,7 +115,7 @@ public:
 	static void displayMessage2(uint16 messageId, uint16 hotspotId, uint16 v3);
 	static void startOilBurner(uint16 v1, uint16 v2, uint16 v3);
 	static void transformPlayer(uint16 v1, uint16 v2, uint16 v3);
-	static void jailClose(uint16 v1, uint16 v2, uint16 v3);
+	static void townHallClose(uint16 v1, uint16 v2, uint16 v3);
 	static void checkRoomNumber(uint16 hotspotId, uint16 roomNumber, uint16 v3);
 	static void makeGoewinFollow(uint16 v1, uint16 v2, uint16 v3);
 	static void doorClose(uint16 hotspotId, uint16 v2, uint16 v3);
