@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/lure/surface.cpp $
- * $Id: surface.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/lure/surface.cpp $
+ * $Id: surface.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -156,11 +156,16 @@ void Surface::writeSubstring(uint16 x, uint16 y, Common::String line, int len,
 	const char *sPtr = line.c_str();
 
 	for (int index = 0; (index < len) && (*sPtr != '\0'); ++index, ++sPtr) {
+		int charSize = varLength ? fontSize[(uint8)*sPtr - 32] + 2 : FONT_WIDTH;
+		if (x + charSize >= width())
+			// Passed the right hand edge of the surface
+			break;
+
+		// Write next character
 		writeChar(x, y, (uint8) *sPtr, transparent, colour);
 
 		// Move to after the character in preparation for the next character
-		if (!varLength) x += FONT_WIDTH;
-		else x += fontSize[(uint8)*sPtr - 32] + 2;
+		x += charSize;
 	}
 }
 
@@ -1159,7 +1164,7 @@ static const ItemDesc copyProtectElements[] = {
 	
 	{EN_ANY, 57, 40, 208, 40, WORDING_HEADER, 32},
 	{FR_FRA, 57, 40, 208, 40, WORDING_HEADER, 32},
-	{DE_DEU, 39, 40, 208, 40, WORDING_HEADER, 32},
+	{DE_DEU, 39, 30, 240, 53, WORDING_HEADER, 32},
 	{NL_NLD, 57, 40, 208, 40, WORDING_HEADER, 32},
 	{ES_ESP, 57, 40, 208, 40, WORDING_HEADER, 32},
 	{IT_ITA, 57, 40, 208, 40, WORDING_HEADER, 32},
