@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/saga/actor.cpp $
- * $Id: actor.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/saga/actor.cpp $
+ * $Id: actor.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -1207,7 +1207,7 @@ void Actor::simulSpeech(const char *string, uint16 *actorIds, int actorIdsCount,
 		actor = getActor(actorIds[i]);
 		_activeSpeech.actorIds[i] = actorIds[i];
 		_activeSpeech.speechColor[i] = actor->_speechColor;
-		_activeSpeech.outlineColor[i] = 0; // disable outline
+		_activeSpeech.outlineColor[i] = _vm->KnownColor2ColorId(kKnownColorBlack);
 	}
 	_activeSpeech.actorsCount = actorIdsCount;
 	_activeSpeech.strings[0] = string;
