@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/saga/actor.h $
- * $Id: actor.h 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/saga/actor.h $
+ * $Id: actor.h 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -181,7 +181,8 @@ enum DragonMoveTypes {
 
 struct PathDirectionData {
 	int8 direction;
-	Point coord;	
+	int x;
+	int y;
 };
 
 struct ActorFrameRange {
@@ -268,9 +269,15 @@ struct Location {
 		z = stream.readUint16LE();
 	}
 
+#if 0
+	// Obsolete function, throws warnings in older versions of GCC
+	// (warning: int format, int32 arg)
+	// Keeping it around for debug purposes
 	void debugPrint(int debuglevel = 0, const char *loc = "Loc:") const {
 		debug(debuglevel, "%s %d, %d, %d", loc, x, y, z);
 	}
+#endif
+
 };
 
 class CommonObjectData {
