@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/saga/palanim.cpp $
- * $Id: palanim.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/saga/palanim.cpp $
+ * $Id: palanim.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -30,6 +30,7 @@
 #include "saga/events.h"
 
 #include "saga/palanim.h"
+#include "saga/interface.h"
 
 namespace Saga {
 
@@ -170,7 +171,10 @@ int PalAnim::cycleStep(int vectortime) {
 		}
 	}
 
-	_vm->_gfx->setPalette(pal);
+	// Don't cycle the palette when the map is open
+	// Fixes bug #1900258 - "ITE: Glitch when looking at the map while at the docks"
+	if (_vm->_interface->getMode() != kPanelMap)
+		_vm->_gfx->setPalette(pal);
 
 	event.type = kEvTOneshot;
 	event.code = kPalAnimEvent;
