@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/saga/sndres.cpp $
- * $Id: sndres.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/saga/sndres.cpp $
+ * $Id: sndres.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -103,9 +103,17 @@ SndRes::~SndRes() {
 void SndRes::setVoiceBank(int serial) {
 	if (_voiceSerial == serial) return;
 
+	// Close previous voice bank file
+	if (_voiceSerial >= 0 && _voiceContext->file->isOpen())
+		_voiceContext->file->close();
+
 	_voiceSerial = serial;
 
 	_voiceContext = _vm->_resource->getContext(GAME_VOICEFILE, _voiceSerial);
+
+	// Open new voice bank file
+	if (!_voiceContext->file->isOpen())
+		_voiceContext->file->open(_voiceContext->fileName);
 }
 
 void SndRes::playSound(uint32 resourceId, int volume, bool loop) {
