@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/scumm/imuse_digi/dimuse_bndmgr.cpp $
- * $Id: dimuse_bndmgr.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/scumm/imuse_digi/dimuse_bndmgr.cpp $
+ * $Id: dimuse_bndmgr.cpp 30944 2008-02-23 22:50:18Z sev $
  */
 
 
@@ -281,7 +281,7 @@ int32 BundleMgr::decompressSampleByIndex(int32 index, int32 offset, int32 size,
 		lastBlock = _numCompItems - 1;
 
 	int32 blocksFinalSize = 0x2000 * (1 + lastBlock - firstBlock);
-	*compFinal = (byte *)malloc(blocksFinalSize);
+	*compFinal = new byte[blocksFinalSize];
 	assert(*compFinal);
 	finalSize = 0;
 
@@ -348,7 +348,7 @@ int32 BundleMgr::decompressSampleByName(const char *name, int32 offset, int32 si
 		return final_size;
 	}
 
-	debug(2, "BundleMgr::decompressSampleByName() Failed finding voice %s", name);
+	debug(2, "BundleMgr::decompressSampleByName() Failed finding sound %s", name);
 	return final_size;
 }
 
