@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/scumm/imuse_digi/dimuse_codecs.cpp $
- * $Id: dimuse_codecs.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/scumm/imuse_digi/dimuse_codecs.cpp $
+ * $Id: dimuse_codecs.cpp 30944 2008-02-23 22:50:18Z sev $
  */
 
 
@@ -34,7 +34,7 @@ namespace BundleCodecs {
 uint32 decode12BitsSample(const byte *src, byte **dst, uint32 size) {
 	uint32 loop_size = size / 3;
 	uint32 s_size = loop_size * 4;
-	byte *ptr = *dst = (byte *)malloc(s_size);
+	byte *ptr = *dst = new byte[s_size];
 	assert(ptr);
 
 	uint32 tmp;
