@@ -18,14 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/scumm/imuse_digi/dimuse_music.cpp $
- * $Id: dimuse_music.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/scumm/imuse_digi/dimuse_music.cpp $
+ * $Id: dimuse_music.cpp 30944 2008-02-23 22:50:18Z sev $
  */
 
 
 #include "common/scummsys.h"
 #include "scumm/scumm.h"
 #include "scumm/imuse_digi/dimuse.h"
+#include "scumm/imuse_digi/dimuse_tables.h"
 
 namespace Scumm {
 
@@ -54,7 +55,7 @@ void IMuseDigital::setDigMusicState(int stateId) {
 
 		int offset = _attributes[_digStateMusicMap[num].offset];
 		if (offset == 0) {
-			if (_attributes[_digStateMusicMap[num].atribPos] != 0) {
+			if (_attributes[_digStateMusicMap[num].attribPos] != 0) {
 				num = _digStateMusicMap[num].stateIndex3;
 			} else {
 				num = _digStateMusicMap[num].stateIndex1;
@@ -112,12 +113,12 @@ void IMuseDigital::setDigMusicSequence(int seqId) {
 		} else {
 			playDigMusic(_digSeqMusicTable[num].name, &_digSeqMusicTable[num], 0, true);
 			_nextSeqToPlay = 0;
-			_attributes[DIG_SEQ_OFFSET + num] = 1;
+			_attributes[DIG_SEQ_OFFSET + num] = 1; // _attributes[COMI_SEQ_OFFSET] in Comi are not used as it doesn't have 'room' attributes table
 		}
 	} else {
 		if (_nextSeqToPlay != 0) {
 			playDigMusic(_digSeqMusicTable[_nextSeqToPlay].name, &_digSeqMusicTable[_nextSeqToPlay], 0, true);
-			_attributes[DIG_SEQ_OFFSET + _nextSeqToPlay] = 1;
+			_attributes[DIG_SEQ_OFFSET + _nextSeqToPlay] = 1; // _attributes[COMI_SEQ_OFFSET] in Comi are not used as it doesn't have 'room' attributes table
 			num = _nextSeqToPlay;
 			_nextSeqToPlay = 0;
 		} else {
@@ -132,71 +133,76 @@ void IMuseDigital::setDigMusicSequence(int seqId) {
 	_curMusicSeq = num;
 }
 
-void IMuseDigital::playDigMusic(const char *songName, const imuseDigTable *table, int atribPos, bool sequence) {
+void IMuseDigital::playDigMusic(const char *songName, const imuseDigTable *table, int attribPos, bool sequence) {
 	int hookId = 0;
 
 	if (songName != NULL) {
 		if ((_attributes[DIG_SEQ_OFFSET + 38]) && (!_attributes[DIG_SEQ_OFFSET + 41])) {
-			if ((atribPos == 43) || (atribPos == 44))
+			if ((attribPos == 43) || (attribPos == 44))
 				hookId = 3;
 		}
 
 		if ((_attributes[DIG_SEQ_OFFSET + 46] != 0) && (_attributes[DIG_SEQ_OFFSET + 48] == 0)) {
-			if ((atribPos == 38) || (atribPos == 39))
+			if ((attribPos == 38) || (attribPos == 39))
 				hookId = 3;
 		}
 
 		if ((_attributes[DIG_SEQ_OFFSET + 53] != 0)) {
-			if ((atribPos == 50) || (atribPos == 51))
+			if ((attribPos == 50) || (attribPos == 51))
 				hookId = 3;
 		}
 
-		if ((atribPos != 0) && (hookId == 0)) {
-			if (table->atribPos != 0)
-				atribPos = table->atribPos;
-			hookId = _attributes[DIG_STATE_OFFSET + atribPos];
+		if ((attribPos != 0) && (hookId == 0)) {
+			if (table->attribPos != 0)
+				attribPos = table->attribPos;
+			hookId = _attributes[DIG_STATE_OFFSET + attribPos];
 			if (table->hookId != 0) {
 				if ((hookId != 0) && (table->hookId > 1)) {
-					_attributes[DIG_STATE_OFFSET + atribPos] = 2;
+					_attributes[DIG_STATE_OFFSET + attribPos] = 2;
 				} else {
-					_attributes[DIG_STATE_OFFSET + atribPos] = hookId + 1;
+					_attributes[DIG_STATE_OFFSET + attribPos] = hookId + 1;
 					if (table->hookId < hookId + 1)
-						_attributes[DIG_STATE_OFFSET + atribPos] = 1;
+						_attributes[DIG_STATE_OFFSET + attribPos] = 1;
 				}
 			}
 		}
 	}
 
-	fadeOutMusic(120);
+	if (!songName) {
+		fadeOutMusic(120);
+		return;
+	}
 
 	switch (table->transitionType) {
-		case 0:
-		case 5:
-		case 6:
-			break;
-		case 3:
-		case 4:
-			if (table->filename[0] == 0) {
-				return;
-			}
-			if ((!sequence) && (table->atribPos != 0) &&
-					(table->atribPos == _digStateMusicTable[_curMusicState].atribPos)) {
-				startMusic(table->filename, table->soundId, 0, 127);
-				return;
-			}
+	case 0:
+	case 5:
+		break;
+	case 3:
+	case 4:
+		if (table->filename[0] == 0) {
+			fadeOutMusic(60);
+			return;
+		}
+		if (table->transitionType == 4)
+			_stopingSequence = 1;
+		if ((!sequence) && (table->attribPos != 0) &&
+				(table->attribPos == _digStateMusicTable[_curMusicState].attribPos)) {
+			fadeOutMusicAndStartNew(108, table->filename, table->soundId);
+		} else {
+			fadeOutMusic(108);
 			startMusic(table->filename, table->soundId, hookId, 127);
-			break;
+		}
+		break;
+	case 6:
+		_stopingSequence = 1;
+		break;
 	}
 }
 
 void IMuseDigital::setComiMusicState(int stateId) {
 	int l, num = -1;
 
-	// This happens at the beginning of Part II, but should apparently not
-	// do anything since the correct music is already playing. A left-over
-	// of some kind?
-
-	if (stateId == 4)
+	if (stateId == 4) // look into #1881415 bug, ignore stateId == 4 it's seems needed after all
 		return;
 
 	if (stateId == 0)
@@ -209,7 +215,9 @@ void IMuseDigital::setComiMusicState(int stateId) {
 			break;
 		}
 	}
-	assert(num != -1);
+
+	if (num == -1)
+		return;
 
 	if (_curMusicState == num)
 		return;
@@ -237,14 +245,18 @@ void IMuseDigital::setComiMusicSequence(int seqId) {
 			break;
 		}
 	}
-	assert(num != -1);
+
+	if (num == -1)
+		return;
 
 	if (_curMusicSeq == num)
 		return;
 
 	if (num != 0) {
-		if (_curMusicSeq && ((_comiSeqMusicTable[_curMusicSeq].transitionType == 4) || (_comiSeqMusicTable[_curMusicSeq].transitionType == 6))) {
+		if (_curMusicSeq && ((_comiSeqMusicTable[_curMusicSeq].transitionType == 4)
+				|| (_comiSeqMusicTable[_curMusicSeq].transitionType == 6))) {
 			_nextSeqToPlay = num;
+			return;
 		} else {
 			playComiMusic(_comiSeqMusicTable[num].name, &_comiSeqMusicTable[num], 0, true);
 			_nextSeqToPlay = 0;
@@ -266,68 +278,70 @@ void IMuseDigital::setComiMusicSequence(int seqId) {
 	_curMusicSeq = num;
 }
 
-void IMuseDigital::playComiMusic(const char *songName, const imuseComiTable *table, int atribPos, bool sequence) {
+void IMuseDigital::playComiMusic(const char *songName, const imuseComiTable *table, int attribPos, bool sequence) {
 	int hookId = 0;
 
-	if ((songName != NULL) && (atribPos != 0)) {
-		if (table->atribPos != 0)
-			atribPos = table->atribPos;
-		hookId = _attributes[COMI_STATE_OFFSET + atribPos];
+	if ((songName != NULL) && (attribPos != 0)) {
+		if (table->attribPos != 0)
+			attribPos = table->attribPos;
+		hookId = _attributes[COMI_STATE_OFFSET + attribPos];
 		if (table->hookId != 0) {
 			if ((hookId != 0) && (table->hookId > 1)) {
-				_attributes[COMI_STATE_OFFSET + atribPos] = 2;
+				_attributes[COMI_STATE_OFFSET + attribPos] = 2;
 			} else {
-				_attributes[COMI_STATE_OFFSET + atribPos] = hookId + 1;
+				_attributes[COMI_STATE_OFFSET + attribPos] = hookId + 1;
 				if (table->hookId < hookId + 1)
-					_attributes[COMI_STATE_OFFSET + atribPos] = 1;
+					_attributes[COMI_STATE_OFFSET + attribPos] = 1;
 			}
 		}
 	}
 
+	if (!songName) {
+		fadeOutMusic(120);
+		return;
+	}
+
 	switch (table->transitionType) {
-		case 0:
-			fadeOutMusic(120);
-			break;
-		case 8:
-		case 9:
-			setHookId(table->soundId, table->soundId);
-			break;
-		case 1:
-			if (table->filename[0] == 0) {
-				fadeOutMusic(120);
-				return;
-			}
-			fadeOutMusic(120);
-			startMusic(table->filename, table->soundId, 0, 1);
-			setFade(table->soundId, 127, 120);
-			break;
-		case 2:
-			if (table->filename[0] == 0) {
-				fadeOutMusic(60);
-				return;
-			}
+	case 0:
+		break;
+	case 8:
+		setHookIdForMusic(table->hookId);
+		break;
+	case 9:
+		_stopingSequence = 1;
+		setHookIdForMusic(table->hookId);
+		break;
+	case 2:
+	case 3:
+	case 4:
+	case 12:
+		if (table->filename[0] == 0) {
+			fadeOutMusic(60);
+			return;
+		}
+		if (getCurMusicSoundId() == table->soundId)
+			return;
+		if (table->transitionType == 4)
+			_stopingSequence = 1;
+		if (table->transitionType == 2) {
 			fadeOutMusic(table->fadeOutDelay);
 			startMusic(table->filename, table->soundId, table->hookId, 127);
-			break;
-		case 3:
-		case 4:
-		case 12:
-			if (table->filename[0] == 0) {
-				fadeOutMusic(60);
-				return;
-			}
+			return;
+		}
+		if ((!sequence) && (table->attribPos != 0) &&
+				(table->attribPos == _comiStateMusicTable[_curMusicState].attribPos)) {
+			fadeOutMusicAndStartNew(table->fadeOutDelay, table->filename, table->soundId);
+		} else if (table->transitionType == 12) {
+			TriggerParams trigger;
+			strcpy(trigger.marker, "exit"); trigger.fadeOutDelay = table->fadeOutDelay;
+			strcpy(trigger.filename, table->filename); trigger.soundId = table->soundId;
+			trigger.hookId = table->hookId; trigger.volume = 127;
+			setTrigger(&trigger);
+		} else {
 			fadeOutMusic(table->fadeOutDelay);
-			if ((!sequence) && (table->atribPos != 0) &&
-					(table->atribPos == _comiStateMusicTable[_curMusicState].atribPos)) {
-				startMusic(table->filename, table->soundId, 0, 127);
-				return;
-			}
-			if (table->transitionType == 12) {
-				startMusic(table->filename, table->soundId, table->hookId, 127);
-			} else {
-				startMusic(table->filename, table->soundId, hookId, 127);
-			}
-			break;
+			startMusic(table->filename, table->soundId, hookId, 127);
+		}
+		break;
 	}
 }
 
@@ -418,19 +432,19 @@ void IMuseDigital::playFtMusic(const char *songName, int opcode, int volume) {
 	fadeOutMusic(200);
 
 	switch (opcode) {
-		case 0:
-		case 4:
-			break;
-		case 1:
-		case 2:
-		case 3:
-			{
-				int soundId = getSoundIdByName(songName);
-				if (soundId != -1) {
-					startMusic(soundId, volume);
-				}
+	case 0:
+	case 4:
+		break;
+	case 1:
+	case 2:
+	case 3:
+		{
+			int soundId = getSoundIdByName(songName);
+			if (soundId != -1) {
+				startMusic(soundId, volume);
 			}
-			break;
+		}
+		break;
 	}
 }
 
