@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/scumm/imuse_digi/dimuse_sndmgr.h $
- * $Id: dimuse_sndmgr.h 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/scumm/imuse_digi/dimuse_sndmgr.h $
+ * $Id: dimuse_sndmgr.h 30944 2008-02-23 22:50:18Z sev $
  */
 
 #ifndef SCUMM_IMUSE_DIGI_SNDMGR_H
@@ -65,6 +65,12 @@ private:
 		byte *ptr;			// pointer to sync
 	};
 
+	struct Marker {
+		int32 pos;			// position Markaer in sound data
+		int32 length;		// length of marker string
+		char *ptr;			// pointer to string
+	};
+
 public:
 
 	struct SoundDesc {
@@ -81,6 +87,9 @@ public:
 		int numSyncs;		// number of Syncs
 		Sync *sync;
 
+		int numMarkers;		// number of Markers
+		Marker *marker;
+
 		bool endFlag;
 		bool inUse;
 		byte *allData;
@@ -110,10 +119,10 @@ private:
 	byte _disk;
 	BundleDirCache *_cacheBundleDir;
 
-	bool openMusicBundle(SoundDesc *sound, int disk);
-	bool openVoiceBundle(SoundDesc *sound, int disk);
+	bool openMusicBundle(SoundDesc *sound, int &disk);
+	bool openVoiceBundle(SoundDesc *sound, int &disk);
 
-	void countElements(byte *ptr, int &numRegions, int &numJumps, int &numSyncs);
+	void countElements(byte *ptr, int &numRegions, int &numJumps, int &numSyncs, int &numMarkers);
 
 public:
 
@@ -133,6 +142,7 @@ public:
 	int getNumJumps(SoundDesc *soundDesc);
 	int getRegionOffset(SoundDesc *soundDesc, int region);
 	int getJumpIdByRegionAndHookId(SoundDesc *soundDesc, int region, int hookId);
+	bool checkForTriggerByRegionAndMarker(SoundDesc *soundDesc, int region, const char *marker);
 	int getRegionIdByJumpId(SoundDesc *soundDesc, int jumpId);
 	int getJumpHookId(SoundDesc *soundDesc, int number);
 	int getJumpFade(SoundDesc *soundDesc, int number);
