@@ -18,12 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/scumm/imuse_digi/dimuse_tables.cpp $
- * $Id: dimuse_tables.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/scumm/imuse_digi/dimuse_tables.cpp $
+ * $Id: dimuse_tables.cpp 30944 2008-02-23 22:50:18Z sev $
  */
 
 
-#include "scumm/imuse_digi/dimuse.h"
+//#include "scumm/imuse_digi/dimuse.h"
+#include "scumm/imuse_digi/dimuse_tables.h"
 
 namespace Scumm {
 
@@ -447,7 +448,7 @@ const imuseComiTable _comiSeqMusicTable[] = {
 	{3, 2445, "seqSkullArrive",  0, 0,   60, "2445-S~1.IMX"},
 	{3, 2450, "seqFloat",        0, 0,   60, "2450-C~1.IMX"},
 	{2, 2451, "seqFall",         0, 1,   60, "2450-C~1.IMX"},
-	{2, 2452, "seqUmbrella",     0, 0,   60, "2450-C~1.IMX"},
+	{2, 2452, "seqUmbrella",     0, 2,   60, "2450-C~1.IMX"},
 	{3, 2460, "seqFight",        0, 0,   60, "2460-F~1.IMX"},
 	{0, 2465, "seqLAVE_RIDE",    0, 0,    0, ""},
 	{0, 2470, "seqMORE_SLAW",    0, 0,    0, ""},
