@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-0/engines/scumm/scumm.cpp $
- * $Id: scumm.cpp 30459 2008-01-12 23:07:51Z sev $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-11-1/engines/scumm/scumm.cpp $
+ * $Id: scumm.cpp 30944 2008-02-23 22:50:18Z sev $
  *
  */
 
@@ -2116,8 +2116,8 @@ void ScummEngine_v7::scummLoop_handleSound() {
 	ScummEngine_v6::scummLoop_handleSound();
 	if (_imuseDigital) {
 		_imuseDigital->flushTracks();
-		// In CoMI and the full (non-demo) version of The Dig, also invoke IMuseDigital::refreshScripts
-		if ( ((_game.id == GID_DIG) && (!(_game.features & GF_DEMO))) || (_game.id == GID_CMI) )
+		// In CoMI and the Dig the full (non-demo) version invoke IMuseDigital::refreshScripts 
+		if ((_game.id == GID_DIG || _game.id == GID_CMI) && !(_game.features & GF_DEMO))
 			_imuseDigital->refreshScripts();
 	}
 	if (_smixer) {
