@@ -1,6 +1,5 @@
 #include <cxxtest/TestSuite.h>
 
-#include "common/stdafx.h"
 #include "common/scummsys.h"
 #include <stddef.h>
 
@@ -12,7 +11,7 @@ struct TestStruct {
 	uint16 z;
 	uint32 a;
 	byte b;
-};
+} PACKED_STRUCT;
 
 #include <common/pack-end.h>	// END STRUCT PACKING
 
