@@ -540,6 +540,7 @@ begin_credits("Credits");
 	  begin_section("Kyra");
 		  add_person("Torbj&ouml;rn Andersson", "eriktorbjorn", "VQA Player");
 		  add_person("Oystein Eftevaag", "vinterstum", "");
+		  add_person("Florian Kagerer", "athrxx", "");
 		  add_person("Gregory Montoir", "cyx", "");
 		  add_person("Johannes Schickel", "LordHoto", "");
 	  end_section();
@@ -682,6 +683,7 @@ begin_credits("Credits");
 
 	  begin_section("BeOS");
 		  add_person("Stefan Parviainen", "", "");
+		  add_person("Luc Schrijvers", "Begasus", "");
 	  end_section();
 
 	  begin_section("Debian GNU/Linux");
@@ -752,7 +754,6 @@ begin_credits("Credits");
 		  add_person("Janne Huttunen", "", "V3 actor mask support, Dig/FT SMUSH audio");
 		  add_person("Kov&aacute;cs Endre J&aacute;nos", "", "Several fixes for Simon1");
 		  add_person("Jeroen Janssen", "japj", "Numerous readability and bugfix patches");
-		  add_person("Florian Kagerer", "athrxx", "Various Kyrandia 1 FM-Towns code contributions");
 		  add_person("Andreas Karlsson", "Sprawl", "Initial port for EPOC/SymbianOS");
 		  add_person("Claudio Matsuoka", "", "Daily Linux builds");
 		  add_person("Thomas Mayer", "", "PSP port contributions");
