@@ -2,13 +2,15 @@
 // oder projektspezifische Includedateien, die hufig benutzt, aber
 // in unregelmigen Abstnden gendert werden.
 //
+#ifndef __STDAFX_H__
+#define __STDAFX_H__
 
+#ifdef _MSC_VER
 #pragma once
 
-
 #include <iostream>
 #include <tchar.h>
-
+#endif
 
 typedef unsigned char byte;
 typedef unsigned char uint8;
@@ -21,6 +23,7 @@ typedef signed long int32;
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <assert.h>
 
 struct CptObj {
@@ -30,4 +33,5 @@ struct CptObj {
 	uint16 type;
 	//uint16 id;
 };
-// TODO: Verweisen Sie hier auf zustzliche Header, die Ihr Programm erfordert
+
+#endif // __STDAFX_H__
